@@ -8,6 +8,8 @@ Font::TTF::OldMort - Glyph Metamorphosis table in a font
 
 =head1 INSTANCE VARIABLES
 
+=over 
+
 =item version
 
 table version number (Fixed: currently 1.0)
@@ -111,6 +113,8 @@ Insertion table:
 
 =back
 
+=back
+
 =head1 METHODS
 
 =cut
@@ -123,6 +127,10 @@ use IO::File;
 
 @ISA = qw(Font::TTF::Table);
 
+=over
+
+=back 
+
 =head2 $t->read
 
 Reads the table into memory
@@ -699,8 +707,16 @@ None known
 
 =head1 AUTHOR
 
-Jonathan Kew L<Jonathan_Kew@sil.org>. See L<Font::TTF::Font> for copyright and
-licensing.
+Jonathan Kew L<http://scripts.sil.org/FontUtils>. 
 
-=cut
 
+=head1 LICENSING
+
+Copyright (c) 1998-2014, SIL International (http://www.sil.org) 
+
+This module is released under the terms of the Artistic License 2.0. 
+For details, see the full text of the license in the file LICENSE.
+
+
+
+=cut
\ No newline at end of file
